@@ -247,6 +247,8 @@ def main():
                             help="don't print anything while working")
     plain_options.add_argument('--skip-config-files', action="store_true", default=False,
                             help='ignore config file settings')
+    plain_options.add_argument('--allow-local-file-access', action="store_true", default=False,
+                            help='Allow local file system references')
     plain_options.add_argument('-r', '--remove-pis', action='store_true', default=False,
                             help='Remove XML processing instructions')
     plain_options.add_argument('-u', '--utf8', action='store_true',
@@ -400,6 +402,8 @@ def main():
         sys.exit()
 
     # --- Parse and validate arguments ---------------------------------
+    # tempates_dir
+    options.template_dir = options.template_dir or default_options.template_dir
 
     if (options.docfile or options.manpage) and not options.list_symbols:
         options.list_symbols = default_options.list_symbols
@@ -525,7 +529,6 @@ def main():
     xml2rfc.log.verbose = options.verbose
 
     # Parse the document into an xmlrfc tree instance
-    options.template_dir = options.template_dir or default_options.template_dir
     parser = xml2rfc.XmlRfcParser(source,
                                   options=options,
                                   templates_path=options.template_dir,
