@@ -599,10 +599,10 @@ _slash_replacements = [
             
 def build_dataurl(mime, data, base64enc=False):
     if base64enc:
-        data = quote(base64.b64encode(data))
+        data = quote(base64.b64encode(data), safe='/~')
         url = "data:%s;base64,%s" % (mime, data)
     else:
-        data = quote(data)
+        data = quote(data, safe='/~')
         url = "data:%s,%s" % (mime, data)
     return url
 
@@ -648,6 +648,7 @@ def iscomment(e):
 def hastext(e, ignore=[]):
     "Return a list of text-level immediate children"
     head = [ e.text ] if e.text and e.text.strip() else []
+    ignore = set(ignore + ['t'])
     items = ( head + [ c for c in e.iterchildren() if not (isblock(c) or iscomment(c) or (c.tag in ignore))]
                    + [ c.tail for c in e.iterchildren() if c.tail and c.tail.strip() ] )
     return items
