@@ -52,7 +52,7 @@ class HtmlRfcWriter(BaseRfcWriter):
         self.cref_counter = 0
         
         # Initialize templates directory
-        self.templates_dir = templates_dir or \
+        self.template_dir = templates_dir or \
                              os.path.join(os.path.dirname(xml2rfc.__file__),
                                           'templates')
 
@@ -60,7 +60,7 @@ class HtmlRfcWriter(BaseRfcWriter):
         self.templates = {}
         for filename in ['base.html',
                          'address_card.html']:
-            file = open(os.path.join(self.templates_dir, filename), 'r')
+            file = open(os.path.join(self.template_dir, filename), 'r')
             self.templates[filename] = string.Template(file.read())
             file.close()
         # Buffers to aggregate various elements before processing template
